@@ -406,9 +406,6 @@ The base glyph is GB (associated to CCS); the component is GC (CC)."
             (compute-glyph c font-list)))
          (compute-lower-glyphs ()
             (loop for i from (char-code #\a) upto (char-code #\z)
-                  do (compute-glyph (code-char i) font-list)))
-         (compute-upper-glyphs ()
-            (loop for i from (char-code #\A) upto (char-code #\Z)
                   do (compute-glyph (code-char i) font-list))))
     (do ((i 0))
         ((= i (length string)))
