@@ -1,5 +1,5 @@
 ;;; This file is part of Cedilla.
-;;; Copyright (C) 2002 by Juliusz Chroboczek.
+;;; Copyright (C) 2002-2009 by Juliusz Chroboczek.
 
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -13,12 +13,6 @@
 
 (defpackage "CEDILLA"
     (:use "CL")
-    (:export "CEDILLA" "CEDILLA-MAIN"))
-
-(in-package "CEDILLA")
-
-;;; CLISP is getting saner by the day
-(eval-when (load compile eval)
-  (let ((p (or (find-package "EXT") (find-package "LISP"))))
-    (import (find-symbol "QUIT" p))
-    (import (find-symbol "*ARGS*" p))))
+    (:export "CEDILLA" "CEDILLA-MAIN" "*EXTERNAL-FORMAT-UTF8*")
+    #+CLISP (:import-from "EXT" "*ARGS*" "QUIT")
+    #+CCL (:import-from "CCL" "QUIT"))
